<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>Database</name>
    <message>
        <location filename="../../libs/utils/database.cpp" line="496"/>
        <source>WARNING : %1 database already in use</source>
        <translation>ATTENTION : la base de données %1 est déjà en cours d&apos;utilisation</translation>
    </message>
    <message>
        <location filename="../../libs/utils/database.cpp" line="657"/>
        <source>ERROR : Database %1 is not readable. Path : %2</source>
        <translation>ERREUR : La base de données %1 n&apos;est pas lisible. Chemin : %2</translation>
    </message>
    <message>
        <location filename="../../libs/utils/database.cpp" line="649"/>
        <source>ERROR : Database %1 is not readable. Host: %2</source>
        <translation>ERREUR : La base de données %1 n&apos;est pas lisible. Hôte : %2</translation>
    </message>
    <message>
        <location filename="../../libs/utils/database.cpp" line="639"/>
        <source>ERROR : Database `%1` is not readable. Path : %2</source>
        <translation>ERREUR : La base %1 n&apos;est pas lisible. Chemin %2</translation>
    </message>
    <message>
        <location filename="../../libs/utils/database.cpp" line="684"/>
        <source>ERROR : Database %1 is not writable. Path : %2.</source>
        <translation>ERREUR : La base de données %1 n&apos;est pas inscriptible. Chemin : %2.</translation>
    </message>
    <message>
        <location filename="../../libs/utils/database.cpp" line="725"/>
        <source>INFO : database %1 connection = %2</source>
        <translation>INFO : Base de données %1 connexion : %2</translation>
    </message>
    <message>
        <location filename="../../libs/utils/database.cpp" line="915"/>
        <source>Database Scheme Error : wrong number of fields for table %1</source>
        <translation>Erreur de schéma de base de données : nombre de champs incorrect, table %1</translation>
    </message>
    <message>
        <location filename="../../libs/utils/database.cpp" line="924"/>
        <source>Database Scheme Error : field number %1 differs : %2 instead of %3 in table %4</source>
        <translation>Erreur de schéma de base de données : champs numéro %1 différe : %2 au lieu de %3 dans la table %4</translation>
    </message>
    <message>
        <location filename="../../libs/utils/database.cpp" line="1716"/>
        <source>Can not create table %1</source>
        <translation>Impossible de créer la table %1</translation>
    </message>
</context>
<context>
    <name>LineEditEchoSwitcher</name>
    <message>
        <location filename="../../libs/utils/widgets/lineeditechoswitcher.cpp" line="62"/>
        <source>Display/Hide text</source>
        <translation>Afficher/cacher le texte</translation>
    </message>
</context>
<context>
    <name>Log</name>
    <message>
        <location filename="../../libs/utils/log.cpp" line="113"/>
        <source>SQL Error : Driver : %1, Database : %2, Query : %3</source>
        <translation>SQL Erreur : pilote %1, base %2, requête %3</translation>
    </message>
    <message>
        <location filename="../../libs/utils/log.cpp" line="118"/>
        <source>%1 : %2 - SQL Error : Driver : %3, Database : %4, Query : %5</source>
        <translation>%1 : %2 - SQL Erreur : Pilote : %3, Base : %4, Requête : %5</translation>
    </message>
    <message>
        <location filename="../../libs/utils/log.cpp" line="135"/>
        <source>%1 : %2 - Database: %3, Host: %4, Port: %5, User:%6, Pass:%7</source>
        <translation>%1 : %2 - Base : %3, Hôte : %4, Port : %5, Utilisateur : %6, Mot de passe : %7</translation>
    </message>
    <message>
        <location filename="../../libs/utils/log.cpp" line="149"/>
        <source>%1 ms : %2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../libs/utils/log.cpp" line="222"/>
        <source>Unable to save %1 : Error %2</source>
        <translation>Impossible de sauvegarder %1 : Erreur %2</translation>
    </message>
    <message>
        <location filename="../../libs/utils/log.cpp" line="237"/>
        <source>Debugging informations</source>
        <translation>Informations de déboggage</translation>
    </message>
    <message>
        <location filename="../../libs/utils/log.cpp" line="242"/>
        <source>********** ERRORS *********
</source>
        <translation>********** ERREURS *********
</translation>
    </message>
    <message>
        <location filename="../../libs/utils/log.cpp" line="261"/>
        <source>********** MESSAGES *********
</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QAbstractXmlTreeModel</name>
    <message>
        <location filename="../../libs/utils/qabstractxmltreemodel.cpp" line="92"/>
        <source>Can not read XML file content %1</source>
        <translation>Impossible de lire le contenu du fichier XML %1</translation>
    </message>
    <message>
        <location filename="../../libs/utils/qabstractxmltreemodel.cpp" line="95"/>
        <source>Reading file: %1</source>
        <translation>Fichier lu : %1</translation>
    </message>
    <message>
        <location filename="../../libs/utils/qabstractxmltreemodel.cpp" line="99"/>
        <source>Can not open XML file %1</source>
        <translation>Impossible d&apos;ouvrir le fichier XML %1</translation>
    </message>
</context>
<context>
    <name>Serializer</name>
    <message>
        <location filename="../../libs/utils/serializer.cpp" line="269"/>
        <location filename="../../libs/utils/serializer.cpp" line="330"/>
        <location filename="../../libs/utils/serializer.cpp" line="388"/>
        <source>Can not deserialize to QHash.</source>
        <translation>Impossible de désérialiser le QHash.</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <location filename="../../libs/utils/global.cpp" line="392"/>
        <location filename="../../libs/utils/global.cpp" line="395"/>
        <source>Error while retrieve informations of uname under %1</source>
        <translation>Erreur lors de la récupération des informations de uname sous %1</translation>
    </message>
    <message>
        <location filename="../../libs/utils/global.cpp" line="519"/>
        <source>%1 : %2 does not exist. Trying to create it.</source>
        <translation>%1 : %2 n&apos;existe pas. Tentative de création.</translation>
    </message>
    <message>
        <location filename="../../libs/utils/global.cpp" line="522"/>
        <source>Unable to create the %1 : %2.</source>
        <translation>Impossible de créer %1 : %2.</translation>
    </message>
    <message>
        <location filename="../../libs/utils/global.cpp" line="528"/>
        <source>%1 : %2 does not exist.</source>
        <translation>%1 : %2 n&apos;existe pas.</translation>
    </message>
    <message>
        <location filename="../../libs/utils/global.cpp" line="560"/>
        <source>File %1 already exists. Do you want de replace it ?</source>
        <translation>Le fichier %1 existe déjà. Voulez-vous le remplacer ?</translation>
    </message>
    <message>
        <location filename="../../libs/utils/global.cpp" line="565"/>
        <location filename="../../libs/utils/global.cpp" line="571"/>
        <location filename="../../libs/utils/global.cpp" line="587"/>
        <source>Error %1 while trying to save file %2</source>
        <translation>Erreur %1 en tentant de sauvegarder le fichier %2</translation>
    </message>
    <message>
        <location filename="../../libs/utils/global.cpp" line="579"/>
        <location filename="../../libs/utils/global.cpp" line="592"/>
        <source>%1 correctly saved</source>
        <translation>%1 correctement sauvegardé</translation>
    </message>
    <message>
        <location filename="../../libs/utils/global.cpp" line="581"/>
        <source>Save file aborted by user (file already exists) : </source>
        <translation>Sauvegarde annulée par l&apos;utilisateur (le fichier existe déjà) : </translation>
    </message>
    <message>
        <location filename="../../libs/utils/global.cpp" line="604"/>
        <source>Save to file</source>
        <translation>Sauvegarde dans le fichier</translation>
    </message>
    <message>
        <location filename="../../libs/utils/global.cpp" line="638"/>
        <source>File %1 does not exists or is not readable.</source>
        <translation>Fichier %1 n&apos;existe pas et n&apos;est pas lisible.</translation>
    </message>
    <message>
        <location filename="../../libs/utils/global.cpp" line="644"/>
        <source>Error %1 while trying to open file %2</source>
        <translation>Erreur %1 en essayant d&apos;ouvrir le fichier %2</translation>
    </message>
    <message>
        <location filename="../../libs/utils/global.cpp" line="798"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../../libs/utils/global.cpp" line="873"/>
        <source>This function is not available in this version.</source>
        <translation>Cette fonction n&apos;est pas disponible dans cette version.</translation>
    </message>
    <message>
        <location filename="../../libs/utils/global.cpp" line="874"/>
        <source>You can send an email to developpers and explain your difficulties : freemedforms@googlegroups.com.</source>
        <translation>Vous pouvez envoyer un courriel aux développeurs et expliquer votre problème : freemedforms@googlegroups.com.</translation>
    </message>
    <message>
        <location filename="../../libs/utils/global.cpp" line="915"/>
        <location filename="../../libs/utils/global.cpp" line="916"/>
        <source>License agreement acceptation</source>
        <translation>Agrément de Licence</translation>
    </message>
    <message>
        <location filename="../../libs/utils/global.cpp" line="927"/>
        <source>&lt;b&gt;Before you can use this software, you must agree its license terms&lt;/b&gt;</source>
        <translation>&lt;b&gt;Avant d&apos;utiliser ce logiciel, vous devez accepter les termes de la licence.&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../libs/utils/global.cpp" line="935"/>
        <source>Do you agree these terms ?</source>
        <translation>Acceptez-vous les termes de la licence ?</translation>
    </message>
    <message>
        <location filename="../../libs/utils/global.cpp" line="1004"/>
        <source>%1 is now in fullScreen Mode.</source>
        <translation>%1 est mode plein écran.</translation>
    </message>
    <message>
        <location filename="../../libs/utils/global.cpp" line="1009"/>
        <source>%1 is now in non fullScreen Mode.</source>
        <translation>%1 n&apos;est plus en mode plein écran.</translation>
    </message>
    <message>
        <location filename="../../libs/utils/global.cpp" line="1521"/>
        <source>Token replacement error (%1). Wrong number of parentheses.</source>
        <translation>Erreur lors du remplacement du repère (%1). Nombre incorrect de parenthèses.</translation>
    </message>
</context>
<context>
    <name>Utils::FileNameValidatingLineEdit</name>
    <message>
        <location filename="../../libs/utils/widgets/filenamevalidatinglineedit.cpp" line="95"/>
        <source>Name is empty.</source>
        <translation>Le nom est vide.</translation>
    </message>
    <message>
        <location filename="../../libs/utils/widgets/filenamevalidatinglineedit.cpp" line="104"/>
        <source>Name contains white space.</source>
        <translation>Le nom contient des espaces.</translation>
    </message>
    <message>
        <location filename="../../libs/utils/widgets/filenamevalidatinglineedit.cpp" line="106"/>
        <source>Invalid character &apos;%1&apos;.</source>
        <translation>Caractère &apos;%1&apos; invalide.</translation>
    </message>
    <message>
        <location filename="../../libs/utils/widgets/filenamevalidatinglineedit.cpp" line="117"/>
        <source>Invalid characters &apos;%1&apos;.</source>
        <translation>Caractères &apos;%1&apos; invalides.</translation>
    </message>
    <message>
        <location filename="../../libs/utils/widgets/filenamevalidatinglineedit.cpp" line="127"/>
        <source>Name matches MS Windows device. (%1).</source>
        <translation>Le nom correspond à l&apos;appareil (%1).</translation>
    </message>
</context>
<context>
    <name>Utils::HttpDownloader</name>
    <message>
        <location filename="../../libs/utils/httpdownloader.cpp" line="92"/>
        <source>Start downloading: %1 to %2</source>
        <translation>Début du téléchargement : %1 à %2</translation>
    </message>
    <message>
        <location filename="../../libs/utils/httpdownloader.cpp" line="111"/>
        <source>There already exists a file called %1 in the current directory. Overwrite?</source>
        <translation>Un fichier nommé %1 existe déjà dans le répertoire. Voulez-vous l&apos;écraser ?</translation>
    </message>
    <message>
        <location filename="../../libs/utils/httpdownloader.cpp" line="121"/>
        <location filename="../../libs/utils/httpdownloader.cpp" line="127"/>
        <source>Unable to save the file %1: %2.</source>
        <translation>Impossible de sauvegarder le fichier %1 : %2.</translation>
    </message>
    <message>
        <location filename="../../libs/utils/httpdownloader.cpp" line="133"/>
        <location filename="../../libs/utils/httpdownloader.cpp" line="178"/>
        <location filename="../../libs/utils/httpdownloader.cpp" line="188"/>
        <source>HTTP</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../libs/utils/httpdownloader.cpp" line="135"/>
        <source>Downloading %1
To %2</source>
        <translation>Téléchargement de %1
À %2</translation>
    </message>
    <message>
        <location filename="../../libs/utils/httpdownloader.cpp" line="179"/>
        <location filename="../../libs/utils/httpdownloader.cpp" line="182"/>
        <source>Download failed: %1.</source>
        <translation>Le téléchargement a échoué %1.</translation>
    </message>
    <message>
        <location filename="../../libs/utils/httpdownloader.cpp" line="189"/>
        <source>Redirect to %1 ?</source>
        <translation>Rediriger vers %1 ?</translation>
    </message>
    <message>
        <location filename="../../libs/utils/httpdownloader.cpp" line="208"/>
        <source>Downloaded %1 to current directory.</source>
        <translation>Téléchargement terminé de %1 dans le répertoire courant.</translation>
    </message>
</context>
<context>
    <name>Utils::Internal::UpdateCheckerPrivate</name>
    <message>
        <location filename="../../libs/utils/updatechecker.cpp" line="107"/>
        <source>Error %1 while retreiving update file %2</source>
        <translation>Erreur %1 lors du rapatriement du fichier de mise à jour %2</translation>
    </message>
    <message>
        <location filename="../../libs/utils/updatechecker.cpp" line="131"/>
        <source>* Updates of version : %1</source>
        <translation>* Mises à jour de la version : %1</translation>
    </message>
</context>
<context>
    <name>Utils::PathChooser</name>
    <message>
        <location filename="../../libs/utils/widgets/pathchooser.cpp" line="49"/>
        <source>Choose...</source>
        <translation>Sélectionnez...</translation>
    </message>
    <message>
        <location filename="../../libs/utils/widgets/pathchooser.cpp" line="51"/>
        <source>Browse...</source>
        <translation>Parcourir...</translation>
    </message>
    <message>
        <location filename="../../libs/utils/widgets/pathchooser.cpp" line="174"/>
        <source>Choose Directory</source>
        <translation>Selectionnez un répertoire</translation>
    </message>
    <message>
        <location filename="../../libs/utils/widgets/pathchooser.cpp" line="180"/>
        <source>Choose File</source>
        <translation>Sélectionnez un fichier</translation>
    </message>
    <message>
        <location filename="../../libs/utils/widgets/pathchooser.cpp" line="213"/>
        <source>The path must not be empty.</source>
        <translation>Le chemin ne peut pas être vide.</translation>
    </message>
    <message>
        <location filename="../../libs/utils/widgets/pathchooser.cpp" line="225"/>
        <source>The path &apos;%1&apos; does not exist.</source>
        <translation>Le chemin &apos;%1&apos; n&apos;existe pas.</translation>
    </message>
    <message>
        <location filename="../../libs/utils/widgets/pathchooser.cpp" line="240"/>
        <source>The path &apos;%1&apos; is not a directory.</source>
        <translation>Le chemin &apos;%1&apos; n&apos;est pas un répertoire.</translation>
    </message>
    <message>
        <location filename="../../libs/utils/widgets/pathchooser.cpp" line="248"/>
        <source>The path &apos;%1&apos; is not a file.</source>
        <translation>Le chemin &apos;%1&apos; n&apos;est pas un fichier.</translation>
    </message>
    <message>
        <location filename="../../libs/utils/widgets/pathchooser.cpp" line="267"/>
        <source>Path:</source>
        <translation>Chemin:</translation>
    </message>
</context>
<context>
    <name>Utils::QButtonLineEdit</name>
    <message>
        <location filename="../../libs/utils/widgets/qbuttonlineedit.cpp" line="187"/>
        <source>(press Alt up/down cursor to cycle)</source>
        <translation>(appuyez sur Alt et haut/bas pour faire défiler)</translation>
    </message>
</context>
<context>
    <name>Utils::UpdateChecker</name>
    <message>
        <location filename="../../libs/utils/updatechecker.cpp" line="279"/>
        <source>An update is available. Please check the web site : &lt;a href=&quot;%1&quot;&gt;%1&lt;/a&gt;</source>
        <translation>Une mise à jour est disponible. Veuillez vous rendre sur le site internet &lt;a href=&quot;%1&quot;&gt;%1&lt;/a&gt;</translation>
    </message>
</context>
</TS>
